==> ukui-biometric-auth_1.0.3.orig.tar.gz: ukui-biometric-auth/polkit-agent/i18n_ts/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <source>Form</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation>Biométrique</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Polkit.subject-pid:</source>
        <translation>Polkit.subject-pid:</translation>
    </message>
    <message>
        <source>Vendor:</source>
        <translation>Vendeur:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>La description:</translation>
    </message>
    <message>
        <source>Polkit.caller-pid:</source>
        <translation>Polkit.caller-pid:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Action:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Authentifier</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>in authentication, please wait...</source>
        <translation>en cours d&apos;authentification, veuillez patienter ...</translation>
    </message>
    <message>
        <source>An application is attempting to perform an action that requires privileges. Authentication is required to perform this action.</source>
        <translation>Une application tente d&apos;exécuter une action nécessitant des privilèges. Une authentification est requise pour effectuer cette action.</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Mot de passe: </translation>
    </message>
    <message>
        <source>Authentication failed, please try again.</source>
        <translation>Authentification échouée. Veuillez réessayer.</translation>
    </message>
</context>
<context>
    <name>PolkitListener</name>
    <message>
        <source>Another client is already authenticating, please try again later.</source>
        <translation>Un autre client s&apos;authentifie déjà. Veuillez réessayer ultérieurement.</translation>
    </message>
    <message>
        <source>Authentication failure, please try again.</source>
        <translation>Échec de l&apos;authentification, veuillez réessayer.</translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_1.2.1.orig.tar.gz: ukui-biometric-auth/polkit-agent/i18n_ts/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <source>Form</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation>Biométrique</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Polkit.subject-pid:</source>
        <translation>Polkit.subject-pid:</translation>
    </message>
    <message>
        <source>Vendor:</source>
        <translation>Vendeur:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>La description:</translation>
    </message>
    <message>
        <source>Polkit.caller-pid:</source>
        <translation>Polkit.caller-pid:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Action:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Authentifier</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>in authentication, please wait...</source>
        <translation>en cours d&apos;authentification, veuillez patienter ...</translation>
    </message>
    <message>
        <source>An application is attempting to perform an action that requires privileges. Authentication is required to perform this action.</source>
        <translation>Une application tente d&apos;exécuter une action nécessitant des privilèges. Une authentification est requise pour effectuer cette action.</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Mot de passe: </translation>
    </message>
    <message>
        <source>Authentication failed, please try again.</source>
        <translation>Authentification échouée. Veuillez réessayer.</translation>
    </message>
</context>
<context>
    <name>PolkitListener</name>
    <message>
        <source>Another client is already authenticating, please try again later.</source>
        <translation>Un autre client s&apos;authentifie déjà. Veuillez réessayer ultérieurement.</translation>
    </message>
    <message>
        <source>Authentication failure, please try again.</source>
        <translation>Échec de l&apos;authentification, veuillez réessayer.</translation>
    </message>
    <message>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
